Stan Math Library: Eigen::internal::general_matrix_vector_product< Index, stan::math::var, RowMajor, ConjugateLhs, stan::math::var, ConjugateRhs > Struct Template Reference

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- Class List
- Class Index
- Class Hierarchy
- Class Members

Public Types | Static Public Member Functions | List of all members
Eigen::internal::general_matrix_vector_product< Index, stan::math::var, RowMajor, ConjugateLhs, stan::math::var, ConjugateRhs > Struct Template Reference

`#include <Eigen_NumTraits.hpp>`

## Public Types
enum | { LhsStorageOrder = RowMajor }
typedef stan::math::var | LhsScalar
typedef stan::math::var | RhsScalar
typedef scalar_product_traits< LhsScalar, RhsScalar >::ReturnType | ResScalar

## Static Public Member Functions
static EIGEN_DONT_INLINE void | run (Index rows, Index cols, const LhsScalar *lhs, Index lhsStride, const RhsScalar *rhs, Index rhsIncr, ResScalar *res, Index resIncr, const RhsScalar &alpha)

## Detailed Description

### template<typename Index, bool ConjugateLhs, bool ConjugateRhs>
struct Eigen::internal::general_matrix_vector_product< Index, stan::math::var, RowMajor, ConjugateLhs, stan::math::var, ConjugateRhs >

Definition at line 157 of file Eigen_NumTraits.hpp.

## Member Typedef Documentation

template<typename Index , bool ConjugateLhs, bool ConjugateRhs>

typedef stan::math::var Eigen::internal::general_matrix_vector_product< Index, stan::math::var, RowMajor, ConjugateLhs, stan::math::var, ConjugateRhs >::LhsScalar

Definition at line 160 of file Eigen_NumTraits.hpp.

template<typename Index , bool ConjugateLhs, bool ConjugateRhs>

typedef scalar_product_traits<LhsScalar, RhsScalar>::ReturnType Eigen::internal::general_matrix_vector_product< Index, stan::math::var, RowMajor, ConjugateLhs, stan::math::var, ConjugateRhs >::ResScalar

Definition at line 163 of file Eigen_NumTraits.hpp.

template<typename Index , bool ConjugateLhs, bool ConjugateRhs>

typedef stan::math::var Eigen::internal::general_matrix_vector_product< Index, stan::math::var, RowMajor, ConjugateLhs, stan::math::var, ConjugateRhs >::RhsScalar

Definition at line 161 of file Eigen_NumTraits.hpp.

## Member Enumeration Documentation

template<typename Index , bool ConjugateLhs, bool ConjugateRhs>

anonymous enum

Enumerator
LhsStorageOrder |

Definition at line 164 of file Eigen_NumTraits.hpp.

## Member Function Documentation

template<typename Index , bool ConjugateLhs, bool ConjugateRhs>

static EIGEN_DONT_INLINE void Eigen::internal::general_matrix_vector_product< Index, stan::math::var, RowMajor, ConjugateLhs, stan::math::var, ConjugateRhs >::run | ( | Index | rows,
|  | Index | cols,
|  | const LhsScalar * | lhs,
|  | Index | lhsStride,
|  | const RhsScalar * | rhs,
|  | Index | rhsIncr,
|  | ResScalar * | res,
|  | Index | resIncr,
|  | const RhsScalar & | alpha
| ) |  |
| inlinestatic

Definition at line 167 of file Eigen_NumTraits.hpp.

The documentation for this struct was generated from the following file:

- stan/math/rev/mat/fun/Eigen_NumTraits.hpp

[ Stan Home Page ] © 2011–2016, Stan Development Team.